Interest

Struct Interest 

pub struct Interest(usize);
Readiness event interest.

Specifies the readiness events the caller is interested in when awaiting on I/O resource readiness states.

Tuple Fields

0: usize

Implementations



impl Interest

pub const READABLE: Interest

Interest in all readable events.

Readable interest includes read-closed events.

pub const WRITABLE: Interest

Interest in all writable events.

Writable interest includes write-closed events.

pub const ERROR: Interest

Interest in error events.

Passes error interest to the underlying OS selector. Behavior is platform-specific, read your platform’s documentation.

pub const PRIORITY: Interest

Returns a Interest set representing priority completion interests.

pub const fn is_readable(self) -> bool

Returns true if the value includes readable interest.

Examples
use tokio::io::Interest;

assert!(Interest::READABLE.is_readable());
assert!(!Interest::WRITABLE.is_readable());

let both = Interest::READABLE | Interest::WRITABLE;
assert!(both.is_readable());

pub const fn is_writable(self) -> bool

Returns true if the value includes writable interest.

Examples
use tokio::io::Interest;

assert!(!Interest::READABLE.is_writable());
assert!(Interest::WRITABLE.is_writable());

let both = Interest::READABLE | Interest::WRITABLE;
assert!(both.is_writable());

pub const fn is_error(self) -> bool

Returns true if the value includes error interest.

Examples
use tokio::io::Interest;

assert!(Interest::ERROR.is_error());
assert!(!Interest::WRITABLE.is_error());

let combined = Interest::READABLE | Interest::ERROR;
assert!(combined.is_error());

pub const fn is_priority(self) -> bool

Returns true if the value includes priority interest.

Examples
use tokio::io::Interest;

assert!(!Interest::READABLE.is_priority());
assert!(Interest::PRIORITY.is_priority());

let both = Interest::READABLE | Interest::PRIORITY;
assert!(both.is_priority());

pub const fn add(self, other: Interest) -> Interest

Add together two Interest values.

This function works from a const context.

Examples
use tokio::io::Interest;

const BOTH: Interest = Interest::READABLE.add(Interest::WRITABLE);

assert!(BOTH.is_readable());
assert!(BOTH.is_writable());

pub fn remove(self, other: Interest) -> Option<Interest>

Remove Interest from self.

Interests present in other but not in self are ignored.

Returns None if the set would be empty after removing Interest.

Examples
use tokio::io::Interest;

const RW_INTEREST: Interest = Interest::READABLE.add(Interest::WRITABLE);

let w_interest = RW_INTEREST.remove(Interest::READABLE).unwrap();
assert!(!w_interest.is_readable());
assert!(w_interest.is_writable());

// Removing all interests from the set returns `None`.
assert_eq!(w_interest.remove(Interest::WRITABLE), None);

// Remove all interests at once.
assert_eq!(RW_INTEREST.remove(RW_INTEREST), None);